@@ -38,6 +38,7 @@ static const R_CallMethodDef Callentries[] = {
     {"Cagmart3",      (DL_FUNC) &agmart3,      8},
     {"Cagscore2",     (DL_FUNC) &agscore2,     6},
     {"Ccdecomp",      (DL_FUNC) &cdecomp,      2},
+    {"Ccollapse",     (DL_FUNC) &collapse,     6},
     {"Cconcordance1", (DL_FUNC) &concordance1, 4}, 
     {"Cconcordance2", (DL_FUNC) &concordance2, 6}, 
     {"Cconcordance3", (DL_FUNC) &concordance3, 6},
@@ -57,6 +58,7 @@ static const R_CallMethodDef Callentries[] = {
     {"Cpyears3b",     (DL_FUNC) &pyears3b,    10},
     {"Csurvfitci",    (DL_FUNC) &survfitci,   11},
     {"Csurvfitkm",    (DL_FUNC) &survfitkm,    9},
+    {"Csurvfitresid", (DL_FUNC) &survfitresid,10},
     {"Csurvreg6",     (DL_FUNC) &survreg6,    15},
     {"Csurvreg7",     (DL_FUNC) &survreg7,    21},
     {"Csurvsplit",    (DL_FUNC) &survsplit,    3},
